/******************************************************************************
* Copyright (c) 2005,2006, Novell, Inc.  All rights reserved.
*
* Redistribution and use in source and binary forms, with or without 
* modification, are permitted provided that the following conditions 
* are met:
*
*	- Redistributions of source code must retain the above copyright notice,
*	this list of conditions and the following disclaimer.
*
*	- Redistributions in binary form must reproduce the above copyright notice,
*  	this list of conditions and the following disclaimer in the documentation
*	and/or other materials provided with the distribution.
*
*	- Neither the name of Novell nor the names of its contributors may be
*	used to endorse or promote products derived from this software without
*	specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
******************************************************************************/

#ifndef __SSH_CONFIG_HPP__
#define __SSH_CONFIG_HPP__

#include <openwbem/OW_config.h>
#include <openwbem/OW_String.hpp>
#include <openwbem/OW_DateTime.hpp>
#include <openwbem/OW_CIMObjectPath.hpp>
#include <openwbem/OW_CIMInstance.hpp>
#include <openwbem/OW_Map.hpp>


#include <omc/Base.hpp>

namespace
{
    using namespace OW_NAMESPACE;


	typedef struct SSH_Config_Props
	{
		char *key;
		char *val;
		bool bMultiValPerLine;
		bool bAllowMultiLines;
		char delim;
	};

    typedef Map<String, String> SSHValuesMap;
    typedef SSHValuesMap::value_type sshValue;

	typedef Map<String, SSH_Config_Props> SSHPropSettingsMap;
	typedef SSHPropSettingsMap::value_type sshPropSetting;
}


namespace OMCSSHConfig
{

using namespace OW_NAMESPACE;



class SSHConfig
{
    public:
        SSHConfig();
        SSHConfig(String &directoryPath);
        virtual ~SSHConfig();

        // Init with specified configDirectoryPath 
        // It will setConfigDirectory, updateFileList, and reReadConfigFromFiles
        void init(String &path);

        // re-read the config file
        // see getValue/setValue/flushCache for info on flushModsBeforeReRead
        // if false, will lose all previous mods
        bool reReadConfigFile(bool bFlushModsBeforeReRead);


		static bool isMultiValueProp(const String &prop);
		static bool isMultiLineProp(const String &prop);
		static char getPropDelim(const String &prop);

        // does it have a value
        bool hasValue(String &key);

        // get a value
        // if value exists:  sets the value, returns true
        // if value doesn't exist, returns false
        bool getValue(String &key, String &value);

		// if value is set in config file, return that, otherwise return default
		bool getEffectiveValue(String &key, String &value);

        // get the value that is used if no value is set in the config file
        bool getDefaultValue(String &key, String &value);

        // to add a single value of a multiple value set, modify the set,
        // then call set Value

        // sets a value, must call flushCache() before mod is effected
        // use when modifying many values
        bool setValue(String &key, String &value);

        // sets a value now - don't need to call flushCache()
        bool setValueNow(String &key, String &value, bool bCleanup = true);

        // to remove a single value of a multiple value set, modify the set,
        // then call set Value

        // remove a value - removes all values for that key
        // must call flushCache() before mod is effected
        // use when modifying many values
        bool removeValue(String &key);

        // remove a value now - don't need to call flushCache()
        bool removeValueNow(String &key, bool bCleanup = true);

        bool flushCache();

        bool valToBool(String &value, bool bDefault = false);

        void valToStringArray(String &key,
							String &value, 
                            String strDefault, 
                            StringArray &valArray);

		void valToStringArray(String &value, 
							String strDefault, 
							StringArray &valArray,
							const char *delimiter);

        String valToString(String &value, String strDefault);

        unsigned long valToULong(String &value, unsigned long ulDefault);

        void dump();

    private:
        String          m_configPath;
        SSHValuesMap    m_sshOrigValues;
        SSHValuesMap    m_sshNewValues;
        SSHValuesMap    m_sshRemoveValues;
        SSHValuesMap    m_sshDefaultValues;

		SSHPropSettingsMap m_sshProps;

        bool            m_bFlushNeeded;
};



}	// End of namespace OMCSSHConfig

#endif	// __SMASH_CONFIG_HPP__
