/******************************************************************************
* Copyright (c) 2005,2006, Novell, Inc.  All rights reserved.
*
* Redistribution and use in source and binary forms, with or without 
* modification, are permitted provided that the following conditions 
* are met:
*
*	- Redistributions of source code must retain the above copyright notice,
*	this list of conditions and the following disclaimer.
*
*	- Redistributions in binary form must reproduce the above copyright notice,
*  	this list of conditions and the following disclaimer in the documentation
*	and/or other materials provided with the distribution.
*
*	- Neither the name of Novell nor the names of its contributors may be
*	used to endorse or promote products derived from this software without
*	specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
* LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
******************************************************************************/

#ifndef __SMASH_COMMON_HPP__
#define __SMASH_COMMON_HPP__

#include <openwbem/OW_String.hpp>
#include <openwbem/OW_CIMDateTime.hpp>
#include <openwbem/OW_CIMObjectPath.hpp>
#include <openwbem/OW_ProviderFwd.hpp>

namespace OMCSmash
{

/**
 * Get the system creation class name that is used as the
 * key to many of the CIM objects instrumented by OMC
 * SMASH.
 * @return The system creation class name as a String object.
 */ 
OW_NAMESPACE::String getSystemCreationClassName();

/**
 * Get the name of the the system. This is used as the key to many CIM
 * objects instrumented by OMC SMASH.
 * @return The system name as a String object.
 */
OW_NAMESPACE::String getSystemName();

/**
 * Get the class name that represents the Registered Base System Profile
 * @return A string that contains the class name that should be used
 * to reference the RegisteredBaseServerProfile.
 */
OW_NAMESPACE::String getRegisteredBaseServerProfileClassName();

/**
 * Get the instance ID of the registered base system profile
 * @return A string that contains the Base System Profile Instance ID
 * 
 */
OW_NAMESPACE::String getBaseServerProfileInstanceID();

/**
 * Get the object path of the RegisteredBaseServerProfile
 * object.  This will be referenced multiple times by other 
 * RegisteredProfiles through ReferencedProfile
 * NOTE: This will ALWAYS be created in the Interop namespace
 * @param interopNamespace A string containing the name of the
 *		interop namespace (e.g. /root)
 * 
 * @return The object path for the RegisteredBaseServerProfile
 */
OW_NAMESPACE::CIMObjectPath getBaseServerProfilePath(
	const OW_NAMESPACE::String& interopNameSpace);

/**
 * Get the object path of the computer system in the smash namespace.
 * @return The object patch for the OMC_UnitaryComputerSystem in the
 * smash namespace.
 */
OW_NAMESPACE::CIMObjectPath getComputerSystemObjectPath();


/**
 * Get the name of the smash namespace
 * @return A string that contains the name of the smash namespace
 * 
 */
OW_NAMESPACE::String getSmashNamespaceName();


/**
 * Get the name of the hal namespace
 * @return A string that contains the name of the hal namespace
 * 
 */
OW_NAMESPACE::String getHalNamespaceName();


/**
 * Get the name of the IPMI namespace
 * @return A string that contains the name of the IPMI namespace
 * 
 */
OW_NAMESPACE::String getIpmiNamespaceName();


/**
 * Get the name of the Composite namespace - where composite provider serves 
 * up the aggregated devices, etc
 * @return A string that contains the name of the Composite namespace
 * 
 */
OW_NAMESPACE::String getCompositeNamespaceName();


}	// End of namespace OMCSmash

#endif	// __SMASH_COMMON_HPP__
